@@ -6,6 +6,7 @@ USTファイルとデータを扱うモジュールです。
 import re
 from collections import UserDict, UserList
 from copy import deepcopy
+from functools import lru_cache
 
 
 def main():
@@ -23,36 +24,31 @@ def main():
     input('\nPress Enter to exit.')
 
 
-def notenum_as_abc(notenum):
+@lru_cache()
+def notenum_as_abc(notenum) -> str:
     """
     音階番号をABC表記に変更する(C1=24, C4=)
     """
-    d = {'24': 'C1', '25': 'C#1', '26': 'D1', '27': 'D#1', '28': 'E1', '29': 'F1',
-         '30': 'F#1', '31': 'G1', '32': 'G#1', '33': 'A1', '34': 'A#1', '35': 'B1',
-         '36': 'C2', '37': 'C#2', '38': 'D2', '39': 'D#2', '40': 'E2', '41': 'F2',
-         '42': 'F#2', '43': 'G2', '44': 'G#2', '45': 'A2', '46': 'A#2', '47': 'B2',
-         '48': 'C3', '49': 'C#3', '50': 'D3', '51': 'D#3', '52': 'E3', '53': 'F3',
-         '54': 'F#3', '55': 'G3', '56': 'G#3', '57': 'A3', '58': 'A#3', '59': 'B3',
-         '60': 'C4', '61': 'C#4', '62': 'D4', '63': 'D#4', '64': 'E4', '65': 'F4',
-         '66': 'F#4', '67': 'G4', '68': 'G#4', '69': 'A4', '70': 'A#4', '71': 'B4',
-         '72': 'C5', '73': 'C#5', '74': 'D5', '75': 'D#5', '76': 'E5', '77': 'F5',
-         '78': 'F#5', '79': 'G5', '80': 'G#5', '81': 'A5', '82': 'A#5', '83': 'B5',
-         '84': 'C6', '85': 'C#6', '86': 'D6', '87': 'D#6', '88': 'E6', '89': 'F6',
-         '90': 'F#6', '91': 'G6', '92': 'G#6', '93': 'A6', '94': 'A#6', '95': 'B6',
-         '96': 'C7', '97': 'C#7', '98': 'D7', '99': 'D#7', '100': 'E7', '101': 'F7',
-         '102': 'F#7', '103': 'G7', '104': 'G#7', '105': 'A7', '106': 'A#7', '107': 'B7',
-         '108': 'C8', '109': 'C#8', '110': 'D8', '111': 'D#8', '112': 'E8', '113': 'F8',
-         '114': 'F#8', '115': 'G8', '116': 'G#8', '117': 'A8', '118': 'A#8', '119': 'B8'}
-    if isinstance(notenum, str):
-        return d[notenum]
-    if isinstance(notenum, int):
-        return d[str(notenum)]
-    if isinstance(notenum, (list, tuple)):
-        return [d[str(v)] for v in notenum]
-    raise TypeError("argument 'notenum' must be in [str, int, list, tuple]")
+    d = {'24': 'C1', '25': 'Db1', '26': 'D1', '27': 'Eb1', '28': 'E1', '29': 'F1',
+         '30': 'Gb1', '31': 'G1', '32': 'Ab1', '33': 'A1', '34': 'Bb1', '35': 'B1',
+         '36': 'C2', '37': 'Db2', '38': 'D2', '39': 'Eb2', '40': 'E2', '41': 'F2',
+         '42': 'Gb2', '43': 'G2', '44': 'Ab2', '45': 'A2', '46': 'Bb2', '47': 'B2',
+         '48': 'C3', '49': 'Db3', '50': 'D3', '51': 'Eb3', '52': 'E3', '53': 'F3',
+         '54': 'Gb3', '55': 'G3', '56': 'Ab3', '57': 'A3', '58': 'Bb3', '59': 'B3',
+         '60': 'C4', '61': 'Db4', '62': 'D4', '63': 'Eb4', '64': 'E4', '65': 'F4',
+         '66': 'Gb4', '67': 'G4', '68': 'Ab4', '69': 'A4', '70': 'Bb4', '71': 'B4',
+         '72': 'C5', '73': 'Db5', '74': 'D5', '75': 'Eb5', '76': 'E5', '77': 'F5',
+         '78': 'Gb5', '79': 'G5', '80': 'Ab5', '81': 'A5', '82': 'Bb5', '83': 'B5',
+         '84': 'C6', '85': 'Db6', '86': 'D6', '87': 'Eb6', '88': 'E6', '89': 'F6',
+         '90': 'Gb6', '91': 'G6', '92': 'Ab6', '93': 'A6', '94': 'Bb6', '95': 'B6',
+         '96': 'C7', '97': 'Db7', '98': 'D7', '99': 'Eb7', '100': 'E7', '101': 'F7',
+         '102': 'Gb7', '103': 'G7', '104': 'Ab7', '105': 'A7', '106': 'Bb7', '107': 'B7',
+         '108': 'C8', '109': 'Db8', '110': 'D8', '111': 'Eb8', '112': 'E8', '113': 'F8',
+         '114': 'Gb8', '115': 'G8', '116': 'Ab8', '117': 'A8', '118': 'Bb8', '119': 'B8'}
+    return d[str(notenum)]
 
 
-def load(path, mode='r', encoding='shift-jis'):
+def load(path: str, mode='r', encoding='shift-jis'):
     """
     USTを読み取り
     """
@@ -132,25 +128,22 @@ class Ust(UserList):
         テンポを正常に取得できるようにする
         """
         if not isinstance(l, list):
-            raise TypeError('argument \"l\" must be list instance')
+            raise TypeError('argument "l" must be list instance')
         self.data = l
         self.reload_tempo()
         return self.data
 
     @property
-    def notes(self):
+    def notes(self) -> list:
         """
         全セクションのうち、[#VERSION] と [#SETTING] [#TRACKEND] を除いたノート部分を取得
         """
         return self.data[2:-1]
 
     @notes.setter
-    def notes(self, l):
-        """
-        全セクションのうち、[#VERSION] と [#SETTING] [#TRACKEND] を除いたノート部分を上書き
-        """
+    def notes(self, l: list):
         if not isinstance(l, list):
-            raise TypeError('argument \"l\" must be list instance')
+            raise TypeError('argument "l" must be list instance')
         self.data = self.data[:2] + l + self.data[-1:]
         self.reload_tempo()
         return self.data
@@ -245,7 +238,7 @@ class Ust(UserList):
             extra_note.alternative_tempo = note.tempo
             self.insert(-1, extra_note)
 
-    def write(self, path, mode='w', encoding='shift-jis'):
+    def write(self, path: str, mode='w', encoding='shift-jis') -> str:
         """
         USTをファイル出力
         """
@@ -296,7 +289,7 @@ class Note(UserDict):
         ノートの中身を上書き
         """
         if not isinstance(d, dict):
-            raise TypeError('argument \"d\" must be dictionary instance')
+            raise TypeError('argument "d" must be dictionary instance')
         self.data = d
 
     @property
